@@ -6,6 +6,7 @@ from sdk.models import DecryptRequest
 
 from alibabacloud_dkms_transfer.handlers.kms_transfer_handler import dict_to_body, \
     get_missing_parameter_client_exception, KmsTransferHandler
+from alibabacloud_dkms_transfer.utils import consts
 
 
 class AsymmetricDecryptTransferHandler(KmsTransferHandler):
@@ -13,6 +14,9 @@ class AsymmetricDecryptTransferHandler(KmsTransferHandler):
     def __init__(self, client, action):
         self.client = client
         self.action = action
+        self.response_headers = [consts.MIGRATION_KEY_VERSION_ID_KEY]
+        self.accept_format = "JSON"
+        self.xml_root = "KMS"
 
     def get_client(self):
         return self.client
@@ -21,18 +25,24 @@ class AsymmetricDecryptTransferHandler(KmsTransferHandler):
         return self.action
 
     def build_dkms_request(self, request, runtime_options):
+        self.accept_format = request.get_accept_format()
         if not request.get_CiphertextBlob():
             raise get_missing_parameter_client_exception("CiphertextBlob")
         decrypt_dkms_request = DecryptRequest()
         decrypt_dkms_request.ciphertext_blob = base64.b64decode(request.get_CiphertextBlob())
         decrypt_dkms_request.key_id = request.get_KeyId()
         decrypt_dkms_request.algorithm = request.get_Algorithm()
+        if request.get_KeyVersionId() is not None:
+            decrypt_dkms_request.request_headers = {consts.MIGRATION_KEY_VERSION_ID_KEY: request.get_KeyVersionId()}
         return decrypt_dkms_request
 
     def call_dkms(self, dkms_request, runtime_options):
+        runtime_options.response_headers = self.response_headers
         return self.client.decrypt_with_options(dkms_request, runtime_options)
 
     def transfer_response(self, response):
+        response_headers = response.response_headers
+        key_version_id = response_headers.get(consts.MIGRATION_KEY_VERSION_ID_KEY)
         body = {"KeyId": response.key_id, "Plaintext": base64.b64encode(response.plaintext).decode("utf-8"),
-                "RequestId": response.request_id, "KeyVersionId": None}
-        return codes.OK, None, dict_to_body(body), None
+                "RequestId": response.request_id, "KeyVersionId": key_version_id}
+        return codes.OK, None, dict_to_body(body, self.accept_format, self.xml_root), None
